@@ -39,7 +39,6 @@ except ImportError:  # python2 compatibility
     from collections import Iterator
 
 import os
-import six
 import shlex
 import sys
 import warnings
@@ -63,8 +62,7 @@ def _preprocessStateMachine(lineIter):
     lineno = 0
     retval = ""
 
-    if six.PY3:
-        retval = retval.encode(sys.getdefaultencoding())
+    retval = retval.encode(sys.getdefaultencoding())
 
     while True:
         try:
@@ -81,9 +79,7 @@ def _preprocessStateMachine(lineIter):
 
         ll = l.strip()
         if not ll.startswith("%ksappend"):
-            if six.PY3:
-                l = l.encode(sys.getdefaultencoding())
-            retval += l
+            retval += l.encode(sys.getdefaultencoding())
             continue
 
         # Try to pull down the remote file.
@@ -136,7 +132,7 @@ def preprocessFromString(s):
     s = preprocessFromStringToString(s)
     if s:
         import tempfile
-        (outF, outName) = tempfile.mkstemp("-ks.cfg", "", "/tmp")
+        (outF, outName) = tempfile.mkstemp(suffix="-ks.cfg")
 
         os.write(outF, s)
         os.close(outF)
@@ -153,7 +149,7 @@ def preprocessKickstart(f):
     s = preprocessKickstartToString(f)
     if s:
         import tempfile
-        (outF, outName) = tempfile.mkstemp("-ks.cfg", "", "/tmp")
+        (outF, outName) = tempfile.mkstemp(suffix="-ks.cfg")
 
         os.write(outF, s)
         os.close(outF)
